# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2006 STX Next Sp. z o.o. and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView

class SimpleViewerView(BrowserView):
    """
    SimpleViewer view class.
    """
    
    def getThumb(self):
        """
        Return thumb.
        """
        image_id = self.request.get('id', '')
        size = self.request.get('size', '')
        
        try:
            return self.context.restrictedTraverse('%s/image_%s' %(image_id, size)).data
        except:
            return



# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2006 STX Next Sp. z o.o. and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from simpleviewer_config import SimpleViewerConfig    

class AutoViewerConfig(SimpleViewerConfig):
    """
    View class for autoviewer XML configure data. 
    """
    
    def getImageCaption(self, image):
        """
        Return caption of given image.
        """
        return '<font size="14">%s</font>' % super(AutoViewerConfig, self).getImageCaption(image)
    
    def getImageWidth(self, image):
        """
        Return image_large width.
        """
        try:
            return self.context.restrictedTraverse('%s/image_preview' % image.getId).width
        except:
            return 0
    
    def getImageHeight(self, image):
        """
        Return image_large width.
        """
        try:
            return self.context.restrictedTraverse('%s/image_preview' % image.getId).height
        except:
            return 0


from setuptools import setup, find_packages

setup (
    name = 'stxnext.flashgallery',
    version = '0.1.1',
    author = 'STX Next Sp. z o.o, Wojciech Lichota',
    author_email = 'info@stxnext.pl, wojciech.lichota@stxnext.pl',
    description = 'Integration of SimpleViewer and AutoViewer photo galleries with Plone.',
    long_description = open('README.txt').read(),
    keywords = 'python plone gallery photo flash',
    platforms = ['any'],
    url = 'http://stxnext.pl/open-source/stxnext.flashgallery',
    license = 'Zope Public License, Version 2.1 (ZPL)',
    packages = find_packages('src'),
    include_package_data = True,
    package_dir = {'':'src'},
    namespace_packages = ['stxnext'],
    zip_safe = False,
    install_requires = ['setuptools'],
    
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Framework :: Zope2',
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Natural Language :: English',
        'Programming Language :: Python',
        ]
    )


# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2006 STX Next Sp. z o.o. and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from Products.CMFCore.utils import getToolByName
from Products.Five import BrowserView

class SimpleViewerConfig(BrowserView):
    """
    Base view class for simpleviewer and autoviewer XML configure data. 
    """
    
    def getImagesInFolder(self):
        """
        Return list of images.
        """
        pc = getToolByName(self.context, 'portal_catalog')
        return pc(object_provides='Products.ATContentTypes.interface.image.IATImage', 
                  path={'query': '/'.join(self.context.getPhysicalPath()), 'depth': 1},
                  sort_on='getObjPositionInParent')
    
    def getImageCaption(self, image):
        """
        Return caption of given image.
        """
        result = []
        
        if image.Title:
            result.append('<B>%s</B><BR />' % image.Title)
        
        if image.Description:
            result.append(image.Description.replace('\r', ''))
            result.append('<BR />')
        
        result.append('<A href="%s" target="_blank"><U>Original size</U></A>' % image.getURL())
        
        return '<BR />'.join(result)
    